@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2010';
+our $VERSION = '0.2011';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
 use MIDI::Util qw(dura_size set_time_signature);
@@ -433,9 +433,9 @@ sub combinatorial {
     my $size = dura_size( $opts->{duration} );
 
     my @items = $opts->{patterns}
-        ? $opts->{patterns}->@*
+        ? @{ $opts->{patterns} }
         : sort map { join '', @$_ }
-            variations_with_repetition( [ keys $opts->{vary}->%* ], $opts->{beats} );
+            variations_with_repetition( [ keys %{ $opts->{vary} } ], $opts->{beats} );
 
     for my $pattern (@items) {
         next if $pattern =~ /^0+$/;
@@ -465,7 +465,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2010
+version 0.2011
 
 =head1 SYNOPSIS
 
